@@ -1,6 +1,6 @@
 package Bundle::CPAN;
-
-$VERSION = '1.81';
+use strict;
+$VERSION = '1.82';
 
 1;
 
@@ -16,6 +16,10 @@ C<perl -MCPAN -e 'install Bundle::CPAN'>
 
 =head1 CONTENTS
 
+Digest::SHA
+
+Module::Signature
+
 File::Temp
 
 File::Spec
@@ -36,8 +40,6 @@ Text::Glob
 
 Module::Build
 
-Digest::SHA
-
 CPAN
 
 =head1 DESCRIPTION
